@@ -9,6 +9,7 @@ Thanks for curlconverter.
 """
 import argparse
 import os
+import platform
 
 import execjs
 
@@ -82,9 +83,14 @@ lang = parser.parse_args().lang
 
 def run():
     try:
+        if lang not in support_lang:
+            return "Sorry, this lang is currently not supported."
+
         ret = ctx.call("curl", curl_code, lang).split("#NB.")[0]
+        if "windows" in platform.system().lower():
+            return "\n" + f"Output: {lang.capitalize().center(7)}".center(50).join(["=" * 52 + "\n=", "=\n" + "=" * 52]) + f"\n{ret}"
         return "\n" + f"\033[1;31;40mOutput: {lang.capitalize().center(7)}\033[0m".center(64).\
             join(["\033[1;32;40m=\033[0m" * 52 + "\n\033[1;32;40m=\033[0m", "\033[1;32;40m=\033[0m\n" +
                   "\033[1;32;40m=\033[0m" * 52]) + f"\n{ret}"
     except:
-        return "Error! Please check your curl code."
+        return "\nError! Please check your curl code."
